==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Effect/stereo/translations/stereo_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>EffectStereoFactory</name>
    <message>
        <location filename="../effectstereofactory.cpp" line="30"/>
        <source>Extra Stereo Plugin</source>
        <translation>Extra Stereo-plug-in</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="50"/>
        <source>About Extra Stereo Plugin</source>
        <translation>Over de Extra Stereo-plug-in</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="51"/>
        <source>Qmmp Extra Stereo Plugin</source>
        <translation>Extra Stereo-plug-in voor Qmmp</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="53"/>
        <source>Based on the Extra Stereo Plugin for Xmms by Johan Levin</source>
        <translation>Gebaseerd op de Extra Stereo-plug-in voor Xmms, gemaakt door Johan Levin</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Extra Stereo Plugin Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="31"/>
        <source>Effect intensity:</source>
        <translation>Effectintensiteit:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="57"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.6.tar.bz2: qmmp-2.2.6/src/plugins/Effect/stereo/translations/stereo_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>EffectStereoFactory</name>
    <message>
        <location filename="../effectstereofactory.cpp" line="30"/>
        <source>Extra Stereo Plugin</source>
        <translation>Extra Stereo-plug-in</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="49"/>
        <source>About Extra Stereo Plugin</source>
        <translation>Over de Extra Stereo-plug-in</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="50"/>
        <source>Qmmp Extra Stereo Plugin</source>
        <translation>Extra Stereo-plug-in voor Qmmp</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="52"/>
        <source>Based on the Extra Stereo Plugin for Xmms by Johan Levin</source>
        <translation>Gebaseerd op de Extra Stereo-plug-in voor Xmms, gemaakt door Johan Levin</translation>
    </message>
</context>
<context>
    <name>StereoSettingsDialog</name>
    <message>
        <location filename="../stereosettingsdialog.ui" line="14"/>
        <source>Extra Stereo Plugin Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <location filename="../stereosettingsdialog.ui" line="31"/>
        <source>Effect intensity:</source>
        <translation>Effectintensiteit:</translation>
    </message>
    <message>
        <location filename="../stereosettingsdialog.ui" line="54"/>
        <source>-</source>
        <translation>-</translation>
    </message>
</context>
</TS>
